<?php

declare(strict_types=1);

namespace Drupal\ckeditor5_template\Plugin\CKEditor5Plugin;

use Drupal\ckeditor5\Plugin\CKEditor5PluginConfigurableTrait;
use Drupal\ckeditor5\Plugin\CKEditor5PluginDefault;
use Drupal\ckeditor5\Plugin\CKEditor5PluginConfigurableInterface;
use Drupal\ckeditor5\Plugin\CKEditor5PluginElementsSubsetInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\editor\EditorInterface;


class Template extends CKEditor5PluginDefault implements CKEditor5PluginConfigurableInterface {

  use CKEditor5PluginConfigurableTrait;
  
  /**
 * CKEditor 5 Template plugin.
 *
 * @internal
 */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $config = $this->getConfiguration();

    $form['file_path'] = [
      '#title' => 'Template file location',
      '#type' => 'textfield',
      '#required' => TRUE,
      '#description' => 'Enter the path to the template file which should be used.',
      '#default_value' => $config['file_path'] ?? '',
    ];

    return $form;
  }


  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
    if (!file_exists(DRUPAL_ROOT . $form_state->getValue('file_path'))) {
      $form_state->setErrorByName('file_path', 'Template file not found.');
    }
  }


  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['file_path'] = $form_state->getValue('file_path');
  }


  /**
   * {@inheritdoc}
   */
  public function getDynamicPluginConfig(array $static_plugin_config, EditorInterface $editor): array {
    $static_plugin_config['template']['file_path'] = $this->configuration['file_path'];
    return $static_plugin_config;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'file_path' => '/modules/contrib/ckeditor5_template/template/ckeditor5_template.json.example'
    ];
  }
}